==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebActivePaneEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActivePaneEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDetailDescription, _super);
    function WebActivePaneEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.g = null;
        return _this;
    }
    WebActivePaneEventArgsDetailDescription.prototype.get_type = function () {
        return "WebActivePaneEventArgsDetail";
    };
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "newPane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("NewPane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "oldPane", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("OldPane");
        },
        enumerable: true,
        configurable: true
    });
    WebActivePaneEventArgsDetailDescription.$t = markType(WebActivePaneEventArgsDetailDescription, 'WebActivePaneEventArgsDetailDescription', Description.$);
    WebActivePaneEventArgsDetailDescription.__marshalByValue = true;
    WebActivePaneEventArgsDetailDescription.__marshalByValueAlias = "ActivePaneEventArgsDetail";
    return WebActivePaneEventArgsDetailDescription;
}(Description));
export { WebActivePaneEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebActivePaneEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActivePaneEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActivePaneEventArgsDetailDescription, _super);
    function WebActivePaneEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.i = null;
        return _this;
    }
    WebActivePaneEventArgsDetailDescription.prototype.get_type = function () {
        return "WebActivePaneEventArgsDetail";
    };
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "newPane", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("NewPane");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDetailDescription.prototype, "oldPane", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("OldPane");
        },
        enumerable: false,
        configurable: true
    });
    WebActivePaneEventArgsDetailDescription.$t = markType(WebActivePaneEventArgsDetailDescription, 'WebActivePaneEventArgsDetailDescription', Description.$);
    WebActivePaneEventArgsDetailDescription.__marshalByValue = true;
    WebActivePaneEventArgsDetailDescription.__marshalByValueAlias = "ActivePaneEventArgsDetail";
    return WebActivePaneEventArgsDetailDescription;
}(Description));
export { WebActivePaneEventArgsDetailDescription };
